@@ -1,6 +1,5 @@
 import base64
 from bertdotbill.logger import Logger
-import json
 
 logger = Logger().init_logger(__name__)
 
@@ -14,9 +13,13 @@ class Topics():
 
     logger.info('Retrieving available topics')
     topics = self.settings.get('topics', {})
-
-    if isinstance(topics, list):
+    if len(topics) > 0:
       logger.info('Successfully retrieved available topics')
+    else:
+      logger.warning('No topics retrieved')
+    logger.debug(f'Available topics: {topics}')
+    if isinstance(topics, dict):
       return {'topics': topics}
     else:
-      logger.error("Improperly structured 'topics' config block, seek --help")
\ No newline at end of file
+      logger.error("Improperly structured 'topics' config block, seek --help")
+      return {'topics': {}}
\ No newline at end of file
